@@ -44,9 +44,12 @@ class ValidatedJSONField(JSONField):
 
     @cached_property
     def _get_default(self):
-        obj = [] if self.isArray else {}
-        if(self.json_validator_cls):
-            self.json_validator_cls.validate(obj)
+        try:
+            obj = [] if self.isArray else {}
+            if(self.json_validator_cls):
+                self.json_validator_cls.validate(obj)
+        except:
+            obj = None
         return lambda: obj
 
     def run_validators(self, value):
@@ -66,9 +69,9 @@ class ValidatedJSONField(JSONField):
 
         self.isArray = False
         if(self.schema is not None):
-            if(default==list or default==[]):
+            if(default==list or default==[] or self.schema.get("type","").lower()=="array"):
                 self.isArray=True
-            elif(default==dict or default=={}):
+            elif(default==dict or default=={} or self.schema.get("type","").lower()=="object"):
                 self.isArray=False
             elif(default is not None):
                 print("#WARNING# ValidatedJSONField: default argument is not allowed, as default is taken from schema", default)
